@@ -12,7 +12,7 @@ class ConsoleDestination(Destination):
         """
         if color is None:
             return text
-        elif type(color) is list:
+        elif isinstance(color, list):
             return "".join([c.ansi() for c in color]) + f"{text}{ANSI_RESET}"
         else:
             return f"{color.ansi()}{text}{ANSI_RESET}"
